import argparse
import json
import sys

from .tokeniz import tokenize


def get_args():
    arg_parser = argparse.ArgumentParser()
    arg_parser.add_argument('document_file',
                            type=argparse.FileType(),
                            default=sys.stdin)
    arg_parser.add_argument('-l', '--language', help='Follow ISO 639-1.')
    return arg_parser.parse_args()


def main():
    args = get_args()

    print(json.dumps(tokenize(args.document_file.read(),
                              language=args.language),
                     ensure_ascii=False,
                     indent="\t"))


if __name__ == "__main__":
    main()



import iso639
import langdetect
import nltk
import MeCab
import nlnormaliz


__all__ = ['tokenize']


def tokenize(document, language=None):
    if language is not None and not iso639.is_valid639_1(language):
        raise ValueError('"{}" is not a valid ISO 639-1 code.'
                         .format(language))

    document = nlnormaliz.normalize(document)

    return {
        'en': tokenize_english,
        'ja': tokenize_japanese,
    }[language or langdetect.detect(document)](document)


def tokenize_english(document):
    return [nltk.tokenize.word_tokenize(sentence.strip())
            for sentence in nltk.tokenize.sent_tokenize(document.strip())]


def tokenize_japanese(document):
    sentence_tokenizer = nltk.RegexpTokenizer(
        '[^{0}]+(?:[{0}]+|$)'.format('!?.！？。．'))

    return [list(sentence_to_words_in_japanese(sentence.strip()))
            for sentence
            in sentence_tokenizer.tokenize(document.strip())]


def sentence_to_words_in_japanese(sentence):
    tagger = MeCab.Tagger()
    tagger.parse('')  # prevent UnicodeDecodeError

    node = tagger.parseToNode(sentence)

    while node != None:
        if node.surface != '':
            yield node.surface

        node = node.next

    raise StopIteration()  # Need to be done manually somehow



import re
import setuptools


setuptools.setup(
    name="nltokeniz",
    version=re.search(r"__version__ *= *'([0-9]+\.[0-9]+\.[0-9]+)' *\n",
                      open("nltokeniz/__init__.py").read()).group(1),
    description="Natural language tokenizer for documents in Python",
    long_description=open("README.md").read(),
    license="Public Domain",
    author="Yota Toyama",
    author_email="raviqqe@gmail.com",
    url="https://github.com/raviqqe/nltokeniz.py/",
    packages=["nltokeniz"],
    entry_points={
            "console_scripts": ["nltokeniz=nltokeniz.__main__:main"]
    },
    install_requires=["iso639", "langdetect", "nlnormaliz", "nltk"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: Public Domain",
        "Natural Language :: English",
        "Natural Language :: Japanese",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Topic :: Text Processing :: Linguistic",
    ],
)
